# Licensecheck

[Licensecheck Index](../README.md#licensecheck-index) / Licensecheck

> Auto-generated documentation for [licensecheck](../../../licensecheck/__init__.py) module.

- [Licensecheck](#licensecheck)
  - [Modules](#modules)

## Modules

- [Module](./module.md)
- [Checker](./checker.md)
- [Cli](./cli.md)
- [Fmt](./fmt.md)
- [License Matrix](license_matrix/index.md)
- [Packageinfo](./packageinfo.md)
- [Resolvers](resolvers/index.md)
- [Session](./session.md)
- [Types](./types.md)